@@ -13,15 +13,15 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
-from Tkinter import *   # GUI stuff
-from gausssum import gausssumgui
+from tkinter import *   # GUI stuff
+import gausssum.gausssumgui
 
 if __name__=="__main__":
 
     root = Tk()
     root.title("GaussSum")
 
-    app = gausssumgui.App(root,sys.argv)   # Set up the app...
+    app = gausssum.gausssumgui.App(root,sys.argv)   # Set up the app...
 
     mainloop()  # ...and sit back
 
